/****************************************************************************
 *                                                                          
 * Title:   Setting of Sweep Mode
 *
 * Purpose: This example shows how to set frequency sweep mode.
 *
 ****************************************************************************/

#include <ansi_c.h>
#include "rssiam.h"

/*** Macros & definitions ***************************************************/

#define CHECKERR( fCal ) \
    { \
        fCalStartTime = clock();\
        error = (fCal);\
        status = error;\
        printf(" Line %ld (%ld ms): %s\n", __LINE__,\
            (fCalTime = (clock() - fCalStartTime)), #fCal);\
        if (error != VI_SUCCESS)\
            {\
            rssiam_error_message (io, error, error_message);\
            printf("\tFunction Call Status: 0x%08X, %s\n", error, error_message);\
            rssiam_error_query(io, &error, error_message);\
            printf("\tInstrument Error: 0x%X, %s\n", error, error_message);\
            }\
    }

#define RESOURCE_NAME   "am" // "USB::0xAAD::0x5::100011" // Resource name

/*** Main *******************************************************************/

int main (int argc, char *argv[])
{
    ViStatus    error               = VI_SUCCESS,
                status              = VI_SUCCESS;
    clock_t     fCalTime            = 0,
                fCalStartTime       = 0;
    ViChar      error_message[256];
    ViSession   io;

    /* Define remote connection parameters (as default values) */

    ViBoolean   IDQuery             = VI_TRUE,
                resetDevice         = VI_TRUE;
    ViRsrc      resourceName        = RESOURCE_NAME;

    CHECKERR (rssiam_init (resourceName, IDQuery, resetDevice, &io));

    printf (

    "\n --- Set Frequency Sweep Mode -------------------------------------------\n\n"
    "\t - Function: Sine\n"
    "\t - Start Frequency: 1.0 kHz\n"
    "\t - Stop Frequency: 10.0 kHz\n"
    "\t - Sweep Direction: Down\n"
    "\t - Sweep Spacing: Log\n"
    "\t - Sweep Time: 1.0 s\n"
    "\t - Sweep Points: 100\n"
    "\n ------------------------------------------------------------------------\n\n"

    );

    /* Output setup */
    CHECKERR (rssiam_funcShap (io, RSSIAM_OUTPUT_FUNC_SIN));
    CHECKERR (rssiam_outpSetup (io, RSSIAM_OUTPUT_SETUP_ON));

    /* Sweep setup */
    CHECKERR (rssiam_freqStar (io, 1.0e3));
    CHECKERR (rssiam_freqStop (io, 10.0e3));
    CHECKERR (rssiam_sweDirection (io, RSSIAM_SWEEP_DIRECTION_DOWN));
    CHECKERR (rssiam_swePoin (io, 100));
    CHECKERR (rssiam_sweSpac (io, RSSIAM_SWEEP_SPAC_LOG));
    CHECKERR (rssiam_sweTime (io, 1.0));
    CHECKERR (rssiam_sweStat (io, RSSIAM_SWEEP_STAT_ON));

    printf ("\n");

    CHECKERR (rssiam_close (io));

    return 0;
}
